@@ -1,16 +1,42 @@
-from django.test import TestCase
-from django.contrib.auth.models import User
-import json
+import datetime
 
+from django.contrib.auth.models import User
+from django.test import TestCase
+from django.test.client import RequestFactory
+from django.utils import simplejson as json
+
+from lizard_ui.configchecker import checker
 from lizard_ui.middleware import TracebackLoggingMiddleware
 from lizard_ui.models import ApplicationScreen
-from lizard_ui.configchecker import checker
+from lizard_ui.templatetags.utility import application_icons
 from lizard_ui.templatetags.utility import dutch_timedelta
 from lizard_ui.templatetags.utility import euro
-from lizard_ui.templatetags.utility import application_icons
+from lizard_ui.templatetags.utility import short_timedelta
+import lizard_ui.views
 
 
-class TestLoginLogout(TestCase):
+class TestViewContextMixin(TestCase):
+
+    def test_alone(self):
+        """ViewContextMixin should work on its own."""
+        view = lizard_ui.views.ViewContextMixin()
+        self.assertEquals(view.get_context_data(),
+                          {'view': view})
+
+    def test_with_inheritance(self):
+        """ViewContextMixin should work with a parent."""
+        class Parent(object):
+            def get_context_data(self, **kwargs):
+                return {'parent': 'daddy'}
+        class Child(lizard_ui.views.ViewContextMixin, Parent):
+            pass
+        view = Child()
+        self.assertEquals(view.get_context_data(),
+                          {'view': view,
+                           'parent': 'daddy'})
+
+
+class TestLoginLogoutIntegration(TestCase):
 
     def setUp(self):
         """Create sample user."""
@@ -21,7 +47,7 @@ class TestLoginLogout(TestCase):
     def test_smoke(self):
         # No parameters: return code 200.
         # Login page must have "login-button".
-        response = self.client.post('/accounts/login/', {})
+        response = self.client.get('/accounts/login/', {})
         self.assertEquals(response.status_code, 200)
         self.assertTrue("#login-button" in response.content)
         # ^^^ That's inside the inline javascript, btw.
@@ -78,6 +104,25 @@ class TestUtility(TestCase):
         self.assertEquals(u'1 dag, 1 minuut', dutch_timedelta(86500))
         dutch_timedelta(None)  # Should not crash
 
+    def test_short_timedelta(self):
+        self.assertEquals(u'4 dagen', short_timedelta(
+                datetime.timedelta(days=4)))
+        self.assertEquals(u'1 dag', short_timedelta(
+                datetime.timedelta(days=1, seconds=5)))
+        self.assertEquals(u'1 dag', short_timedelta(
+                datetime.timedelta(days=1)))
+        self.assertEquals(u'5 uur', short_timedelta(
+                datetime.timedelta(seconds=3600*5 + 300)))
+        self.assertEquals(u'5 uur', short_timedelta(
+                datetime.timedelta(seconds=3600*5)))
+        self.assertEquals(u'5 minuten', short_timedelta(
+                datetime.timedelta(seconds=60*5 + 4)))
+        self.assertEquals(u'5 minuten', short_timedelta(
+                datetime.timedelta(seconds=60*5)))
+        self.assertEquals(u'36 seconde', short_timedelta(
+                datetime.timedelta(seconds=36)))
+        short_timedelta(None)  # Should not crash
+
     def test_application_icons(self):
         """
         The application_icons template tag should never crash. It
@@ -142,3 +187,22 @@ class TestConfigChecker(TestCase):
     def test_smoke(self):
         """Just test that it doesn't crash and burn."""
         checker()
+
+
+class TestExampleBreadcrumbs(TestCase):
+
+    def test_smoke(self):
+        """Just test that it doesn't crash and burn."""
+        request = RequestFactory().get('/example/')
+        response = lizard_ui.views.example_breadcrumbs(request)
+        self.assertEquals(response.status_code, 200)
+
+
+class TestExampleApplicationScreen(TestCase):
+
+    def test_smoke(self):
+        """Just test that it doesn't crash and burn."""
+        request = RequestFactory().get('/example/')
+        response = lizard_ui.views.application_screen(request)
+        self.assertEquals(response.status_code, 200)
+
