@@ -15,6 +15,7 @@ INSTALLED_APPS = [
     'south',
     'compressor',
     'staticfiles',
+    'sentry.client',
     'django_extensions',
     'django_nose',
     'django.contrib.admin',
@@ -68,4 +69,5 @@ STATIC_URL = '/static_media/'
 # static media into STATIC_ROOT/admin.
 ADMIN_MEDIA_PREFIX = STATIC_URL + 'admin/'
 
+STATICFILES_FINDERS = STATICFILES_FINDERS
 LOGGING = setup_logging(BUILDOUT_DIR)
